summaryrefslogtreecommitdiffstats
path: root/src/build.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/build.h')
-rw-r--r--src/build.h10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/build.h b/src/build.h
index 8106faa..51589ef 100644
--- a/src/build.h
+++ b/src/build.h
@@ -56,9 +56,13 @@ struct Plan {
/// Dumps the current state of the plan.
void Dump();
- /// Mark an edge as done building. Used internally and by
- /// tests.
- void EdgeFinished(Edge* edge);
+ enum EdgeResult {
+ kEdgeFailed,
+ kEdgeSucceeded
+ };
+
+ /// Mark an edge as done building (whether it succeeded or failed).
+ void EdgeFinished(Edge* edge, EdgeResult result);
/// Clean the given node during the build.
/// Return false on error.